@@ -22,16 +22,43 @@ from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-import numpy as np
-from pydantic import BaseModel, Field
+# Conditional numpy import
+try:
+    import numpy as np
+    NUMPY_AVAILABLE = True
+except ImportError:
+    NUMPY_AVAILABLE = False
+    np = None
+
+from pydantic import BaseModel, Field, ConfigDict
 
 from ..core.base import Chunk, ChunkingResult
 
 logger = logging.getLogger(__name__)
 
-# Suppress some common warnings from transformers/torch
+# Suppress common warnings from ML libraries
 warnings.filterwarnings("ignore", category=UserWarning, module="transformers")
 warnings.filterwarnings("ignore", category=FutureWarning, module="transformers")
+warnings.filterwarnings("ignore", category=UserWarning, module="torch")
+warnings.filterwarnings("ignore", category=FutureWarning, module="torch")
+
+# Suppress TensorFlow warnings
+import os
+os.environ.setdefault('TF_CPP_MIN_LOG_LEVEL', '2')  # Suppress INFO and WARNING
+os.environ.setdefault('TF_ENABLE_ONEDNN_OPTS', '0')  # Disable oneDNN optimizations
+
+# Suppress additional TensorFlow warnings
+warnings.filterwarnings("ignore", category=UserWarning, module="tensorflow")
+warnings.filterwarnings("ignore", category=FutureWarning, module="tensorflow")
+
+
+def _check_numpy_available() -> None:
+    """Check if numpy is available and raise ImportError if not."""
+    if not NUMPY_AVAILABLE:
+        raise ImportError(
+            "numpy is required for embedding functionality. "
+            "Install it with: pip install chunking-strategy[ml]"
+        )
 
 
 def check_dependency(package_name: str, extra_name: str = None) -> Tuple[bool, str]:
@@ -214,9 +241,10 @@ class EmbeddedChunk(BaseModel):
     model_used: str
     embedding_dim: int
 
-    class Config:
+    model_config = ConfigDict(
         # Allow for better memory efficiency
-        arbitrary_types_allowed = True
+        arbitrary_types_allowed=True
+    )
 
 
 class EmbeddingResult(BaseModel):
@@ -252,6 +280,7 @@ class BaseEmbedder(ABC):
     @abstractmethod
     def embed_text(self, texts: List[str]) -> np.ndarray:
         """Generate embeddings for text content."""
+        _check_numpy_available()
         pass
 
     def _get_device(self) -> str:
@@ -349,6 +378,7 @@ class BaseEmbedder(ABC):
                 return self._create_empty_result(failed_chunks, "All batches failed")
 
             # Combine all embeddings
+            _check_numpy_available()
             embeddings = np.vstack(all_embeddings)
 
             if self.config.normalize_embeddings:
@@ -469,6 +499,13 @@ class SentenceTransformerEmbedder(BaseEmbedder):
 
     def load_model(self) -> None:
         """Load the sentence-transformers model with better error handling."""
+        # Apply protobuf error suppression for the entire model loading process
+        from chunking_strategy import suppress_protobuf_errors
+        with suppress_protobuf_errors():
+            return self._load_model_impl()
+
+    def _load_model_impl(self) -> None:
+        """Internal implementation of model loading."""
         # Check dependencies first
         available, error_msg = check_dependency("sentence_transformers", "text")
         if not available:
@@ -501,6 +538,7 @@ class SentenceTransformerEmbedder(BaseEmbedder):
                 model_kwargs["token"] = token  # Updated API
 
             self.model = SentenceTransformer(model_name, **model_kwargs)
+
             self._is_loaded = True
             logger.info(f"Model loaded successfully on device: {device}")
 
@@ -518,7 +556,9 @@ class SentenceTransformerEmbedder(BaseEmbedder):
                     model_kwargs = {"device": "cpu"}
                     if token:
                         model_kwargs["token"] = token  # Updated API
+
                     self.model = SentenceTransformer(model_name, **model_kwargs)
+
                     self._device = "cpu"
                     self._is_loaded = True
                     logger.info("Model loaded successfully on CPU (fallback)")
@@ -530,6 +570,7 @@ class SentenceTransformerEmbedder(BaseEmbedder):
 
     def embed_text(self, texts: List[str]) -> np.ndarray:
         """Generate embeddings for text content with better error handling."""
+        _check_numpy_available()
         if not self._is_loaded:
             self.load_model()
 
@@ -625,6 +666,7 @@ class CLIPEmbedder(BaseEmbedder):
 
     def embed_text(self, texts: List[str]) -> np.ndarray:
         """Generate embeddings for text content using CLIP."""
+        _check_numpy_available()
         if not self._is_loaded:
             self.load_model()
 
@@ -757,9 +799,12 @@ def print_embedding_summary(result: EmbeddingResult, max_chunks: int = 5) -> Non
             print(f"    Embedding dim: {chunk.embedding_dim}")
 
             # Show embedding statistics
-            embedding_array = np.array(chunk.embedding)
-            print(f"    Embedding stats: mean={embedding_array.mean():.4f}, std={embedding_array.std():.4f}")
-            print(f"    Embedding preview: [{chunk.embedding[0]:.4f}, {chunk.embedding[1]:.4f}, ...]")
+            if NUMPY_AVAILABLE:
+                embedding_array = np.array(chunk.embedding)
+                print(f"    Embedding stats: mean={embedding_array.mean():.4f}, std={embedding_array.std():.4f}")
+                print(f"    Embedding preview: [{chunk.embedding[0]:.4f}, {chunk.embedding[1]:.4f}, ...]")
+            else:
+                print(f"    Embedding preview: [{chunk.embedding[0]:.4f}, {chunk.embedding[1]:.4f}, ...]")
 
             if chunk.content:
                 content_preview = chunk.content[:100] + "..." if len(chunk.content) > 100 else chunk.content
